@@ -2321,7 +2321,9 @@ void gok_scanner_mouse_movement (gint x, gint y)
 	m_MouseX = x;
 	m_MouseY = y;
 	gok_scanner_perform_effects (m_pEffectsMouseMovement);
-	gok_scanner_input_motion_xevie (x, y);
+	if (gok_main_get_use_xevie()) {
+		gok_scanner_input_motion_xevie (x, y);
+	}
 }
 
 /**
@@ -3496,6 +3498,18 @@ gok_scanner_current_state_uses_corepointer (void)
 gboolean 
 gok_scanner_current_state_uses_core_mouse_button(int button)
 {
+	/* Special case dwell mode to always return FALSE?
+	 * This might improve interaction with 'clicker-like' tools
+	 * such as MouseTweaks. Waiting for related investigation to conclude.
+	 * see bug 538004 (and possibly 537827). Probably best if these tools
+	 * use gok in direcselection mode, which will probably require 538004 to
+	 * be fixed.
+	
+	if (!strcmp(m_pAccessMethodCurrent->Name,"dwellselection")){
+		return FALSE;
+	}	
+	 */
+	 
 	switch (button) {
 		case 1:
 			if (   (m_pEffectsLeftButtonDown != NULL)
